@@ -48,6 +48,7 @@
 
 #include <KCoreAddons/KAboutData>
 
+#include <QQmlApplicationEngine>
 #include <QCoreApplication>
 #include <QDesktopServices>
 #include <QDialog>
@@ -98,6 +99,8 @@ public:
 
     std::unique_ptr<ManageHeaderBar> mManageHeaderBar;
 
+    QQmlApplicationEngine *mEngine = nullptr;
+
 };
 
 ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::make_unique<ElisaApplicationPrivate>(this))
@@ -265,13 +268,12 @@ void ElisaApplication::configureShortcuts()
 
 void ElisaApplication::configureElisa()
 {
-#if defined KF5KCMUtils_FOUND && KF5KCMUtils_FOUND
-    KCMultiDialog configurationDialog;
+    if (!d->mEngine)
+    {
+        return;
+    }
 
-    configurationDialog.addModule(QStringLiteral("kcm_elisa_local_file"));
-    configurationDialog.setModal(true);
-    configurationDialog.exec();
-#endif
+    d->mEngine->load(QUrl(QStringLiteral("qrc:/qml/ElisaConfigurationDialog.qml")));
 }
 
 void ElisaApplication::goBack() {}
@@ -325,6 +327,11 @@ void ElisaApplication::initialize()
     Q_EMIT initializationDone();
 }
 
+void ElisaApplication::setQmlEngine(QQmlApplicationEngine *engine)
+{
+    d->mEngine = engine;
+}
+
 void ElisaApplication::initializeModels()
 {
     d->mMusicManager = std::make_unique<MusicListenersManager>();
