@@ -21,7 +21,6 @@
 #include "elisaLib_export.h"
 
 #include <KIOWidgets/KDirModel>
-#include <QMimeDatabase>
 
 class MusicAudioTrack;
 
@@ -33,9 +32,9 @@ public:
 
     enum ColumnsRoles {
         NameRole = Qt::UserRole + 1,
-        ContainerDataRole = Qt::UserRole + 2,
+        FileUrlRole = Qt::UserRole + 2,
         ImageUrlRole = Qt::UserRole + 3,
-        DirectoryRole = Qt::UserRole + 4,
+        IsDirectoryRole = Qt::UserRole + 4,
         IsPlayListRole = Qt::UserRole + 5
     };
 
